@@ -1,7 +1,7 @@
 import os
 import shutil
 import tempo
-
+k=0
 def make(path):
 
 	empty('tempo.py')
@@ -14,8 +14,13 @@ def make(path):
 	fc.close()
 
 def load():
-	t=tempo.tempo
-	return t
+	if k==0:
+		k=k+1
+		load()
+	else:
+		k=0
+		t=tempo.tempo
+		return t
 
 def empty(path):
 	fc=open(path,'w')
